==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>Estilo do indicador</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>Modo de moda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>Alinhar á esquerda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>Alinhar no superior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>Alinhar no centro</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>Manter mostrado</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>Manter oculto</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>Ocultar de xeito inteligente</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>Configuración do molle</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estilo do indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Modo de moda</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Modo eficiente</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Modo clásico</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Modo centrado</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Manter mostrado</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Manter oculto</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar de xeito inteligente</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Configuración do molle</translation>
    </message>
</context>
</TS>
